mindroot.coreplugins.email package
==================================

Submodules
----------

mindroot.coreplugins.email.email\_provider module
-------------------------------------------------

.. automodule:: mindroot.coreplugins.email.email_provider
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.email.imap\_handler module
-----------------------------------------------

.. automodule:: mindroot.coreplugins.email.imap_handler
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.email.mod module
-------------------------------------

.. automodule:: mindroot.coreplugins.email.mod
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.email.services module
------------------------------------------

.. automodule:: mindroot.coreplugins.email.services
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.email.smtp\_handler module
-----------------------------------------------

.. automodule:: mindroot.coreplugins.email.smtp_handler
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.email.test\_batch module
---------------------------------------------

.. automodule:: mindroot.coreplugins.email.test_batch
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.email.test\_email module
---------------------------------------------

.. automodule:: mindroot.coreplugins.email.test_email
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.email.test\_email\_service module
------------------------------------------------------

.. automodule:: mindroot.coreplugins.email.test_email_service
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: mindroot.coreplugins.email
   :members:
   :show-inheritance:
   :undoc-members:
